@@ -2,18 +2,23 @@
 
 from .anthropic import call_anthropic_api
 from .cerebras import call_cerebras_api
+from .gemini import call_gemini_api
 from .groq import call_groq_api
+from .lmstudio import call_lmstudio_api
 from .ollama import call_ollama_api
 from .openai import call_openai_api
 from .openrouter import call_openrouter_api
-from .zai import call_zai_api
+from .zai import call_zai_api, call_zai_coding_api
 
 __all__ = [
     "call_anthropic_api",
     "call_cerebras_api",
+    "call_gemini_api",
     "call_groq_api",
+    "call_lmstudio_api",
     "call_ollama_api",
     "call_openai_api",
     "call_openrouter_api",
     "call_zai_api",
+    "call_zai_coding_api",
 ]
